==> developer-center-api-3.9.11-sources.jar: cn/com/duiba/developer/center/api/domain/param/AppExtraLargeFieldparam.java <==
package cn.com.duiba.developer.center.api.domain.param;

import cn.com.duiba.developer.center.api.domain.enums.BasicSetting.AppEnvJudgeEnum;

import java.io.Serializable;

/**
 * @author JunAngLiu
 * @Title: AppExtraLargeFieldparam
 * @Description:
 * @date 2018/12/2920:21
 */
public class AppExtraLargeFieldparam implements Serializable {
    private static final long serialVersionUID = 2755742746083711722L;

    private Long id;
    /**
     * appId
     */
    private Long appId;

    /**
     * ios 开启状态true 开启，false 关闭
     */
    private Boolean iosOpenStatus;

    /**
     * ios 开启状态true 开启，false 关闭
     */
    private Boolean androidOpenStatus;


    /**
     * 商品详情页 配置跳转开关
     */
    private Boolean itemDetailRedirectStatus;

    /**
     * 配置通用返回首页按钮
     */
    private Boolean switchAppReturnButton;


    /**
     * ios 分享代码
     */
    private String shareIosCode;

    /**
     * android 分享代码
     */
    private String shareAndroidCode;
    /**
     *  唤醒登陆开关
     */
    private Boolean callUpSwtich;

    /**
     * 唤起登录代码
     */
    private String callUpCode;
    /**
     * 唤起登录注册h5开关
     */
    private Boolean callUpRegistH5Swtich;
    /**
     * 唤起登录注册h5代码
     */
    private String callUpRegistH5Code;

    /**
     * app环境判断设置开关
     */
    private Boolean appEnvJudgeSwitch;

    /**
     * app环境判断方式
     * 1，通过ua标识判断
     * 2，通过特定方法判断
     */
    private AppEnvJudgeEnum anEnum;

    /**
     * ua环境判断标识
     */
    private String uaIdentification;
    /**
     * ios判断方法
     */
    private String IosJudgeMethod;
    /**
     * android判断方法
     */
    private String AndroidJudgeMethod;

    /**
     * 商品详情页 跳转配置
     */
    private String itemShareConfig;

    /**
     * 唤端类型:0 兑吧唤端页，1 开发者唤端页
     */
    private Integer callUpType;
    /**
     * (新)开发者唤端页路径
     */
    private String developerCustomCallUpPage;
    /**
     * ios唤端链接
     */
    private String iosDeepLink;
    /**
     * android唤端链接
     */
    private String androidDeepLink;
    /**
     * 关注公众号二维码
     */
    private String wechatQrcode;

    public String getItemShareConfig() {
        return itemShareConfig;
    }

    public void setItemShareConfig(String itemShareConfig) {
        this.itemShareConfig = itemShareConfig;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }


    public String getShareIosCode() {
        return shareIosCode;
    }

    public void setShareIosCode(String shareIosCode) {
        this.shareIosCode = shareIosCode;
    }

    public String getShareAndroidCode() {
        return shareAndroidCode;
    }

    public void setShareAndroidCode(String shareAndroidCode) {
        this.shareAndroidCode = shareAndroidCode;
    }

    public Boolean getIosOpenStatus() {
        return iosOpenStatus;
    }

    public void setIosOpenStatus(Boolean iosOpenStatus) {
        this.iosOpenStatus = iosOpenStatus;
    }

    public Boolean getAndroidOpenStatus() {
        return androidOpenStatus;
    }

    public void setAndroidOpenStatus(Boolean androidOpenStatus) {
        this.androidOpenStatus = androidOpenStatus;
    }

    public String getCallUpCode() {
        return callUpCode;
    }

    public void setCallUpCode(String callUpCode) {
        this.callUpCode = callUpCode;
    }

    public String getCallUpRegistH5Code() {
        return callUpRegistH5Code;
    }

    public void setCallUpRegistH5Code(String callUpRegistH5Code) {
        this.callUpRegistH5Code = callUpRegistH5Code;
    }

    public Boolean getCallUpSwtich() {
        return callUpSwtich;
    }

    public void setCallUpSwtich(Boolean callUpSwtich) {
        this.callUpSwtich = callUpSwtich;
    }

    public Boolean getCallUpRegistH5Swtich() {
        return callUpRegistH5Swtich;
    }

    public void setCallUpRegistH5Swtich(Boolean callUpRegistH5Swtich) {
        this.callUpRegistH5Swtich = callUpRegistH5Swtich;
    }

    public AppEnvJudgeEnum getAnEnum() {
        return anEnum;
    }

    public void setAnEnum(AppEnvJudgeEnum anEnum) {
        this.anEnum = anEnum;
    }

    public String getUaIdentification() {
        return uaIdentification;
    }

    public void setUaIdentification(String uaIdentification) {
        this.uaIdentification = uaIdentification;
    }

    public String getIosJudgeMethod() {
        return IosJudgeMethod;
    }

    public void setIosJudgeMethod(String iosJudgeMethod) {
        IosJudgeMethod = iosJudgeMethod;
    }

    public String getAndroidJudgeMethod() {
        return AndroidJudgeMethod;
    }

    public void setAndroidJudgeMethod(String androidJudgeMethod) {
        AndroidJudgeMethod = androidJudgeMethod;
    }

    public Boolean getAppEnvJudgeSwitch() {
        return appEnvJudgeSwitch;
    }

    public void setAppEnvJudgeSwitch(Boolean appEnvJudgeSwitch) {
        this.appEnvJudgeSwitch = appEnvJudgeSwitch;
    }

    public Boolean getItemDetailRedirectStatus() {
        return itemDetailRedirectStatus;
    }

    public void setItemDetailRedirectStatus(Boolean itemDetailRedirectStatus) {
        this.itemDetailRedirectStatus = itemDetailRedirectStatus;
    }

    public Integer getCallUpType() {
        return callUpType;
    }

    public void setCallUpType(Integer callUpType) {
        this.callUpType = callUpType;
    }

    public String getDeveloperCustomCallUpPage() {
        return developerCustomCallUpPage;
    }

    public void setDeveloperCustomCallUpPage(String developerCustomCallUpPage) {
        this.developerCustomCallUpPage = developerCustomCallUpPage;
    }

    public String getIosDeepLink() {
        return iosDeepLink;
    }

    public void setIosDeepLink(String iosDeepLink) {
        this.iosDeepLink = iosDeepLink;
    }

    public String getAndroidDeepLink() {
        return androidDeepLink;
    }

    public void setAndroidDeepLink(String androidDeepLink) {
        this.androidDeepLink = androidDeepLink;
    }

    public String getWechatQrcode() {
        return wechatQrcode;
    }

    public void setWechatQrcode(String wechatQrcode) {
        this.wechatQrcode = wechatQrcode;
    }

    public Boolean getSwitchAppReturnButton() {
        return switchAppReturnButton;
    }

    public void setSwitchAppReturnButton(Boolean switchAppReturnButton) {
        this.switchAppReturnButton = switchAppReturnButton;
    }
}

==> developer-center-api-3.9.51-20231220.062210-2-sources.jar: cn/com/duiba/developer/center/api/domain/param/AppExtraLargeFieldparam.java <==
package cn.com.duiba.developer.center.api.domain.param;

import cn.com.duiba.developer.center.api.domain.enums.BasicSetting.AppEnvJudgeEnum;

import java.io.Serializable;

/**
 * @author JunAngLiu
 * @Title: AppExtraLargeFieldparam
 * @Description:
 * @date 2018/12/2920:21
 */
public class AppExtraLargeFieldparam implements Serializable {
    private static final long serialVersionUID = 2755742746083711722L;

    private Long id;
    /**
     * appId
     */
    private Long appId;

    /**
     * ios 开启状态true 开启，false 关闭
     */
    private Boolean iosOpenStatus;

    /**
     * ios 开启状态true 开启，false 关闭
     */
    private Boolean androidOpenStatus;


    /**
     * 商品详情页 配置跳转开关
     */
    private Boolean itemDetailRedirectStatus;

    /**
     * 配置通用返回首页按钮
     */
    private Boolean switchAppReturnButton;


    /**
     * ios 分享代码
     */
    private String shareIosCode;

    /**
     * android 分享代码
     */
    private String shareAndroidCode;
    /**
     *  唤醒登陆开关
     */
    private Boolean callUpSwtich;

    /**
     * 唤起登录代码
     */
    private String callUpCode;
    /**
     * 唤起登录注册h5开关
     */
    private Boolean callUpRegistH5Swtich;
    /**
     * 唤起登录注册h5代码
     */
    private String callUpRegistH5Code;

    /**
     * app环境判断设置开关
     */
    private Boolean appEnvJudgeSwitch;

    /**
     * app环境判断方式
     * 1，通过ua标识判断
     * 2，通过特定方法判断
     */
    private AppEnvJudgeEnum anEnum;

    /**
     * ua环境判断标识
     */
    private String uaIdentification;
    /**
     * ios判断方法
     */
    private String IosJudgeMethod;
    /**
     * android判断方法
     */
    private String AndroidJudgeMethod;

    /**
     * 商品详情页 跳转配置
     */
    private String itemShareConfig;

    /**
     * 唤端类型:0 兑吧唤端页，1 开发者唤端页
     */
    private Integer callUpType;
    /**
     * (新)开发者唤端页路径
     */
    private String developerCustomCallUpPage;
    /**
     * ios唤端链接
     */
    private String iosDeepLink;
    /**
     * android唤端链接
     */
    private String androidDeepLink;
    /**
     * 关注公众号二维码
     */
    private String wechatQrcode;

    /**
     * 分享标题
     */
    private String title;

    /**
     * 分享副标题
     */
    private String subTitle;

    /**
     * 分享缩略图
     */
    private String smallImage;


    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }


    public String getItemShareConfig() {
        return itemShareConfig;
    }

    public void setItemShareConfig(String itemShareConfig) {
        this.itemShareConfig = itemShareConfig;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }


    public String getShareIosCode() {
        return shareIosCode;
    }

    public void setShareIosCode(String shareIosCode) {
        this.shareIosCode = shareIosCode;
    }

    public String getShareAndroidCode() {
        return shareAndroidCode;
    }

    public void setShareAndroidCode(String shareAndroidCode) {
        this.shareAndroidCode = shareAndroidCode;
    }

    public Boolean getIosOpenStatus() {
        return iosOpenStatus;
    }

    public void setIosOpenStatus(Boolean iosOpenStatus) {
        this.iosOpenStatus = iosOpenStatus;
    }

    public Boolean getAndroidOpenStatus() {
        return androidOpenStatus;
    }

    public void setAndroidOpenStatus(Boolean androidOpenStatus) {
        this.androidOpenStatus = androidOpenStatus;
    }

    public String getCallUpCode() {
        return callUpCode;
    }

    public void setCallUpCode(String callUpCode) {
        this.callUpCode = callUpCode;
    }

    public String getCallUpRegistH5Code() {
        return callUpRegistH5Code;
    }

    public void setCallUpRegistH5Code(String callUpRegistH5Code) {
        this.callUpRegistH5Code = callUpRegistH5Code;
    }

    public Boolean getCallUpSwtich() {
        return callUpSwtich;
    }

    public void setCallUpSwtich(Boolean callUpSwtich) {
        this.callUpSwtich = callUpSwtich;
    }

    public Boolean getCallUpRegistH5Swtich() {
        return callUpRegistH5Swtich;
    }

    public void setCallUpRegistH5Swtich(Boolean callUpRegistH5Swtich) {
        this.callUpRegistH5Swtich = callUpRegistH5Swtich;
    }

    public AppEnvJudgeEnum getAnEnum() {
        return anEnum;
    }

    public void setAnEnum(AppEnvJudgeEnum anEnum) {
        this.anEnum = anEnum;
    }

    public String getUaIdentification() {
        return uaIdentification;
    }

    public void setUaIdentification(String uaIdentification) {
        this.uaIdentification = uaIdentification;
    }

    public String getIosJudgeMethod() {
        return IosJudgeMethod;
    }

    public void setIosJudgeMethod(String iosJudgeMethod) {
        IosJudgeMethod = iosJudgeMethod;
    }

    public String getAndroidJudgeMethod() {
        return AndroidJudgeMethod;
    }

    public void setAndroidJudgeMethod(String androidJudgeMethod) {
        AndroidJudgeMethod = androidJudgeMethod;
    }

    public Boolean getAppEnvJudgeSwitch() {
        return appEnvJudgeSwitch;
    }

    public void setAppEnvJudgeSwitch(Boolean appEnvJudgeSwitch) {
        this.appEnvJudgeSwitch = appEnvJudgeSwitch;
    }

    public Boolean getItemDetailRedirectStatus() {
        return itemDetailRedirectStatus;
    }

    public void setItemDetailRedirectStatus(Boolean itemDetailRedirectStatus) {
        this.itemDetailRedirectStatus = itemDetailRedirectStatus;
    }

    public Integer getCallUpType() {
        return callUpType;
    }

    public void setCallUpType(Integer callUpType) {
        this.callUpType = callUpType;
    }

    public String getDeveloperCustomCallUpPage() {
        return developerCustomCallUpPage;
    }

    public void setDeveloperCustomCallUpPage(String developerCustomCallUpPage) {
        this.developerCustomCallUpPage = developerCustomCallUpPage;
    }

    public String getIosDeepLink() {
        return iosDeepLink;
    }

    public void setIosDeepLink(String iosDeepLink) {
        this.iosDeepLink = iosDeepLink;
    }

    public String getAndroidDeepLink() {
        return androidDeepLink;
    }

    public void setAndroidDeepLink(String androidDeepLink) {
        this.androidDeepLink = androidDeepLink;
    }

    public String getWechatQrcode() {
        return wechatQrcode;
    }

    public void setWechatQrcode(String wechatQrcode) {
        this.wechatQrcode = wechatQrcode;
    }

    public Boolean getSwitchAppReturnButton() {
        return switchAppReturnButton;
    }

    public void setSwitchAppReturnButton(Boolean switchAppReturnButton) {
        this.switchAppReturnButton = switchAppReturnButton;
    }
}
